cordova.define("cordova-plugin-sdkta.sdkta", function(require, exports, module) {
"use strict";
/// <reference path="./types/sdkta.d.ts" />
var exec = cordova.require("cordova/exec");
var Sdkta = /** @class */ (function () {
    function Sdkta() {
    }
    Sdkta.prototype.binToString = function (array) {
        var result = "";
        array.forEach(function (element) {
            result += String.fromCharCode(element);
        });
        return result;
    };
    Sdkta.prototype.stringToBin = function (str) {
        var result = [];
        str.split('').forEach(function (element) {
            result.push(element.charCodeAt(0));
        });
        return result;
    };
    Sdkta.prototype.convertStringToArray = function (dataRequestList, fieldList) {
        if (dataRequestList != undefined) {
            dataRequestList.forEach(function (entry) {
                if (fieldList.indexOf(entry.key) != -1 && entry.value != undefined) {
                    entry.valueArray = sdkta.stringToBin(entry.value);
                    delete entry.value;
                }
            });
        }
        return dataRequestList;
    };
    Sdkta.prototype.convertArrayToString = function (dataResponseString) {
        var dataResponse;
        dataResponse = JSON.parse(dataResponseString);
        if (dataResponse.sdkDataResponseList != undefined) {
            dataResponse.sdkDataResponseList.forEach(function (entry) {
                if (entry.valueArray != undefined) {
                    entry.value = sdkta.binToString(entry.valueArray);
                    delete entry.valueArray;
                }
            });
        }
        return JSON.stringify(dataResponse);
    };
    Sdkta.prototype.initActivation = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, "SDKTA", "initActivation", dataRequestList);
    };
    Sdkta.prototype.pushActivationData = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "pushActivationData", dataRequestList);
    };
    Sdkta.prototype.registerPin = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "registerPin", sdkta.convertStringToArray(dataRequestList, ["pin"]));
    };
    Sdkta.prototype.cancelActivation = function (callback) {
        exec(callback, callback, "SDKTA", "cancelActivation", []);
    };
    Sdkta.prototype.activate = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "activate", sdkta.convertStringToArray(dataRequestList, ["pin", "retry_pin"]));
    };
    Sdkta.prototype.getStatusActivation = function (callback) {
        exec(callback, callback, "SDKTA", "getStatusActivation", []);
    };
    //Authent
    Sdkta.prototype.getTransactions = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "getTransactions", dataRequestList);
    };
    Sdkta.prototype.getContexts = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, "SDKTA", "getContexts", dataRequestList);
    };
    Sdkta.prototype.initAuthentication = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        var callbacks;
        if (dataRequestList != undefined) {
            dataRequestList.forEach(function (entry, index) {
                if (entry.key == "callbacks" && entry.value != undefined) {
                    callbacks = entry.value;
                }
            });
        }
        exec(function (data) {
            data = JSON.parse(data);
            if (data[0] == "callback") {
                callback(data[1]);
            }
            else if (data[0] == "onAuthenticationStart" && callbacks.onAuthenticationStart != undefined) {
                callbacks.onAuthenticationStart();
            }
            else if (data[0] == "onAuthenticationSucceeded" && callbacks.onAuthenticationSucceeded != undefined) {
                callbacks.onAuthenticationSucceeded(data[1]);
            }
            else if (data[0] == "onAuthenticationFailed" && callbacks.onAuthenticationFailed != undefined) {
                callbacks.onAuthenticationFailed(data[1]);
            }
            else if (data[0] == "onAuthenticationError" && callbacks.onAuthenticationError != undefined) {
                callbacks.onAuthenticationError(data[1]);
            }
            else if (data[0] == "onAuthenticationFinish" && callbacks.onAuthenticationFinish != undefined) {
                callbacks.onAuthenticationFinish(data[1]);
            }
        }, callback, "SDKTA", "initAuthentication", dataRequestList);
    };
    Sdkta.prototype.cancelInitAuthentication = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "cancelInitAuthentication", dataRequestList);
    };
    ;
    Sdkta.prototype.accept = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, "SDKTA", "accept", sdkta.convertStringToArray(dataRequestList, ["pin"]));
    };
    Sdkta.prototype.refuse = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "refuse", dataRequestList);
    };
    //PIN
    Sdkta.prototype.initChangePin = function (callback) {
        exec(function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, "SDKTA", "initChangePin", []);
    };
    Sdkta.prototype.checkPin = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, function (dataResponse) {
            callback(sdkta.convertArrayToString(dataResponse));
        }, "SDKTA", "checkPin", sdkta.convertStringToArray(dataRequestList, ["pin"]));
    };
    Sdkta.prototype.changePin = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "changePin", sdkta.convertStringToArray(dataRequestList, ["pin"]));
    };
    //Others
    Sdkta.prototype.checkSDK = function (request, callback) {
        if (typeof request == "string") {
            exec(callback, callback, "SDKTA", "checkSDK", [request]);
        }
        else {
            exec(callback, callback, "SDKTA", "checkSDKList", request);
        }
    };
    Sdkta.prototype.deactivate = function (callback, force) {
        if (force != true) { // here was error in original sdtka.js
            force = false;
        }
        exec(callback, callback, "SDKTA", "deactivate", [force]);
    };
    Sdkta.prototype.updateSSEInfo = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "updateSSEInfo", dataRequestList);
    };
    Sdkta.prototype.notify = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "notify", dataRequestList);
    };
    Sdkta.prototype.retrieveSSEInfo = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "retrieveSSEInfo", dataRequestList);
    };
    Sdkta.prototype.getProfiles = function (callback, dataRequestList) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "getProfiles", dataRequestList);
    };
    Sdkta.prototype.setHeaders = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "setHeaders", dataRequestList);
    };
    Sdkta.prototype.resetHeaders = function (callback) {
        exec(callback, callback, "SDKTA", "resetHeaders", []);
    };
    // Authentication Factor
    Sdkta.prototype.isAFAvailable = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "isAFAvailable", dataRequestList);
    };
    Sdkta.prototype.initRegisterAF = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "initRegisterAF", dataRequestList);
    };
    Sdkta.prototype.registerAF = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        var callbacks;
        if (dataRequestList != undefined) {
            dataRequestList.forEach(function (entry, index) {
                if (entry.key == "callbacks" && entry.value != undefined) {
                    callbacks = entry.value;
                }
            });
        }
        exec(callback, callback, "SDKTA", "registerAF", dataRequestList);
    };
    Sdkta.prototype.cancelRegisterAF = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "cancelRegisterAF", dataRequestList);
    };
    Sdkta.prototype.unregisterAF = function (dataRequestList, callback) {
        if (dataRequestList == null) {
            dataRequestList = [];
        }
        exec(callback, callback, "SDKTA", "unregisterAF", dataRequestList);
    };
    return Sdkta;
}());
var sdkta = new Sdkta();
module.exports = sdkta;

});
