cordova.define("fr.laposte.disf.mutualise.cordova.plugins.cropcircle.cropcircle", function(require, exports, module) {
//cordova.define("fr.laposte.disf.mutualise.cordova.plugins.cropcircle.cropcircle", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	var FROM_GALLERY = "ACTION_CHOOSE_IN_GALLERY";
	var FROM_PHOTO = "ACTION_TAKE_PICTURE";
	var FORMAT_PNG = "PNG";
	var FORMAT_JPEG = "JPEG";
	
	/**
	 * Appel promessise du plugin Cordova
	 * @param action
	 * @param imageSizeInPixels
	 * @param imageFormat ("PNG" ou "JPEG" ou "JPG")
	 * @param screenOrientation
	 * @param $q librairie de gestion de promesses (obligatoire à partir du FwAD v3)
	 * @returns Q.promise
	 */
	function requestNewImage(action,imageSizeInPixels,imageFormat,screenOrientation,$q) {
		console.log("CropCircle.requestNewImage (action="+action+", "+imageSizeInPixels+", imageFormat="+imageFormat+", screenOrientation="+screenOrientation+")");
		
		var q;

		if($q !== undefined) {
			q = $q;
		} else if(window.Q !== undefined) {
			q = Q;
		} else {
			throw "Pas de Q";
		}

		var defered = q.defer();
		cordova.exec(
			function(res) {
				console.log("CropCircle.requestNewImage - success");
				defered.resolve(res);
			}, 
			function(res) {
				console.log("CropCircle.requestNewImage - failed - code retour="+res);
				defered.reject(res);
			},
		 	'CropCircle',
		 	action,
			[imageFormat,imageSizeInPixels,screenOrientation]);
		console.log("CropCircle.requestNewImage - fin");
		
		return defered.promise;
	}
	
	/**
	 * Donne l'interface de documents
	 * 
	 * @namespace CropCircle
	 */
	var CropCircle = {
		
		SCREEN_ORIENTATION_UNSPECIFIED : -1,
		SCREEN_ORIENTATION_LANDSCAPE : 0,
		SCREEN_ORIENTATION_PORTRAIT : 1,
		SCREEN_ORIENTATION_USER : 2,
		SCREEN_ORIENTATION_BEHIND : 3,
		SCREEN_ORIENTATION_SENSOR : 4,
		SCREEN_ORIENTATION_NOSENSOR : 5,
		SCREEN_ORIENTATION_SENSOR_LANDSCAPE : 6,
		SCREEN_ORIENTATION_SENSOR_PORTRAIT : 7,
		SCREEN_ORIENTATION_REVERSE_LANDSCAPE : 8,
		SCREEN_ORIENTATION_REVERSE_PORTRAIT : 9,
		SCREEN_ORIENTATION_FULL_SENSOR : 10,
		SCREEN_ORIENTATION_USER_LANDSCAPE : 11,
		SCREEN_ORIENTATION_USER_PORTRAIT : 12,
		SCREEN_ORIENTATION_FULL_USER : 13,
		SCREEN_ORIENTATION_LOCKED : 14,

		/**
		 * Nouvelle image a partir de la gallerie
		 * @param imageSizeInPixels
		 * @param imageFormat ("PNG" ou "JPEG")
		 * @param screenOrientation
		 * @param $q librairie de gestion de promesses (obligatoire à partir du FwAD v3)
		 * @function requestNewImageFromGallery
		 */
		requestNewImageFromGallery : function(imageSizeInPixels,imageFormat,screenOrientation,$q) {
			console.log("CropCircle.requestNewImageFromGallery");
			return requestNewImage(FROM_GALLERY, imageSizeInPixels, imageFormat, screenOrientation, $q);
		}, 
		/**
		 * Nouvelle image a partir de l'appareil photo
		 * @param imageSizeInPixels
		 * @param imageFormat ("PNG" ou "JPEG" ou "JPG")
		 * @param screenOrientation
		 * @param $q librairie de gestion de promesses (obligatoire à partir du FwAD v3)
		 * @function requestNewImageFromPhoto
		 */
		requestNewImageFromPhoto : function(imageSizeInPixels,imageFormat,screenOrientation,$q) {
			console.log("CropCircle.requestNewImageFromPhoto");
			return requestNewImage(FROM_PHOTO, imageSizeInPixels, imageFormat, screenOrientation, $q);
		},
		
		/**
		 * reencode l'image afin de la rendre compatible avec un affichage dans un <div> via CSS background
		 * @function reencoderImage
		 * @param largeur de l'image retournee
		 * @param hauteur de l'image retournee
		 * @param format de l'image a generer ("png","jpeg","gif")
		 * @param imageDataURL l'image a retailler sous forme de String encodee en Base64 (avec le prefixe indentifiant le format ex : "data:image/png;base64,...")
		 * @param $q librairie de gestion de promesses (obligatoire à partir du FwAD v3)
		 * @callback fonction appelee une fois le traitement termine et a laquelle l'image retaillee est passee en parametre
		 */
		reencoderImage: function(largeur, hauteur, formatImage, imageDataURL, callback) {
			//console.log("plugin CropCircle : reencoderImage");
			/*
			console.log(
				"reencoderImage" +
				" largeur=" + largeur + " hauteur = " + hauteur + " formatImage = " + formatImage +
				" callback = " + callback);
			*/
			// si l'image est vide on sort
			if (!imageDataURL || imageDataURL === "") {
				console.log("CropCircle.reencoderImage : image vide");
				callback(imageDataURL);
			}
			var dataURL = null;
			var formatsReencodage = ["png","jpeg","gif"];
			
			if (!formatImage || formatImage === "" || formatsReencodage.indexOf(formatImage.toLowerCase()) === -1) {
				formatImage = "png"; // jpeg = format par defaut pour generer les images
			}
			console.log("CropCircle.reencoderImage : imageDataURL.length="+imageDataURL.length);
			console.log("CropCircle.reencoderImage : imageDataURL="+imageDataURL.substr(0,100));
			var photoOriginale = new Image();
			photoOriginale.src = imageDataURL;
			console.log("CropCircle.reencoderImage - 2 ");
			photoOriginale.onload = function() {
				photo = this;
				//console.log("CropCircle.CropCircle.reencoderImage : photo originale="+photo.width+"x"+photo.height);
				// on cree un canvas aux dimensions de la photo 
				var canvas = document.getElementById("canvasRedimPhoto");
				canvas.width = largeur;
				canvas.height = hauteur;
				//console.log("photo finale=canvas="+canvas.width+"x"+canvas.height);
				var ctx = canvas.getContext("2d");
				// on centre la photo
				ctx.clearRect(0, 0, canvas.width, canvas.height);
				// on dessine l'image sur le canvas
				ctx.drawImage(photo, 0, 0, largeur, hauteur);
				dataURL = canvas.toDataURL('image/'+formatImage);
				//console.log("CropCircle.reencoderImage : taille image base64 = "+dataURL.length+" octets");
				callback(dataURL);
			}
			
		}
	}
	
	module.exports = CropCircle;
//});

});
