cordova.define("fr.laposte.disf.mutualise.cordova.plugins.documentmanager.documentmanager", function(require, exports, module) {
//cordova.define("fr.laposte.disf.mutualise.cordova.plugins.documentmanager.documentmanager", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	/**
	 * Donne l'interface de documents
	 * 
	 * @namespace Document
	 */
	var DocumentManager = {
		/**
		 * Partage d'un document
		 * 
		 * @function {public void} share
		 * @param {object}
		 *            params
		 * @... {String} data Donnees du document au format base64
		 * @... {String} mimeType Type mime du document. Si non renseigne,
		 *      l'application native tentera de le deviner
		 * @... {String} subject Sujet du message pour le partage
		 * @... {String} text Texte du message pour le partage
		 * @... {String} title Titre de la popup de partage (concerne Android)
		 * @... {String} fileName Nom du fichier
		 * @exception Exception
		 *                si les parametres sont incorrects
		 */
		share : function(params, callbackOk, callbackError) {
			if (!params.data) {
				throw "Erreur : il manque le data";
			}
			if (!params.mimeType) {
				throw "Erreur : il manque le type mime";
			}
			exec(function(e) {
				if(callbackOk != null) {
					callbackOk(e);
				}
			}, function(e) {
				console.log("Erreur : " + e);
				
				if(callbackError != null) {
					callbackError(e);
				}
			}, "DocumentManager", "share", [ params ]);
		},
		/**
		 * Partage d'un document
		 * 
		 * @function {public void} view
		 * @param {object}
		 *            params
		 * @... {String} data Donnees du document au format base64 (si url n'est
		 *      pas renseigne)
		 * @... {String} url URL du document (si data n'est pas renseigne)
		 * @... {String} mimeType Type mime du document. Si non renseigne,
		 *      l'application native tentera de le deviner
		 * @... {String} title Titre de la popup de partage (concerne Android)
		 * @... {String} fileName Nom du fichier
		 * @exception Exception
		 *                si les parametres sont incorrects
		 */
		view : function(params, callbackOk, callbackError) {
			if (params.url && params.data) {
				throw "Erreur : data et url sont renseignes";
			}
			if (!params.url && !params.data) {
				throw "Erreur : ni data ni url renseignes";
			}
			if (params.data && !params.mimeType) {
				throw "Erreur : il manque le type mime";
			}
			exec(function(e) {
				if(callbackOk != null) {
					callbackOk(e);
				}
			}, function(e) {
				console.log("Erreur : " + e);
				
				if(callbackError != null) {
					callbackError(e);
				}
			}, "DocumentManager", "view", [ params ]);
		},
		/**
		 * Envoi d'un mail
		 * 
		 * @function {public void} view
		 * @param {object}
		 *            params
		 * @... {String} emailTo adresse mail vers qui envoyer
		 * @... {String} subject Sujet du message pour le partage
		 * @... {String} text Texte du message pour le partage
		 * @... {String} title Titre de la popup de partage (concerne Android)
		 * @exception Exception
		 *                si les parametres sont incorrects
		 */
		sendMail : function(params, callbackOk, callbackError) {
			exec(function(e) {
				if(callbackOk != null) {
					callbackOk(e);
				}
			}, function(e) {
				console.log("Erreur : " + e);
				
				if(callbackError != null) {
					callbackError(e);
				}
			}, "DocumentManager", "sendMail", [ params ]);
		}
	}
	module.exports = DocumentManager;
//});

});
