/**
 * @namespace Date
 */
/**
 * Formate une date selon le format pass en paramtre
 * @function {public String} format
 * @param {String} format de date
  			d  		: jour sur 1 ou 2 chiffres
  			dd 		: jour sur 2 chiffres
  			M  		: mois sur 1 ou 2 chiffres
  			MM		: mois sur 2 chiffres
  			yy		: anne sur 2 chiffres
  			yyyy	: anne sur 4 chiffres
  			h		: heure (format 12h) sur 1 ou 2 chiffres
  			hh		: heure (format 12h) sur 2 chiffres
  			H		: heure (format 24h) sur 1 ou 2 chiffres
  			HH		: heure (format 24h) sur 2 chiffres
  			m		: minutes sur 1 ou 2 chiffres
  			mm		: minutes sur 2 chiffres
  			s		: secondes sur 1 ou 2 chiffres
  			ss		: secondes sur 2 chiffres
  			l		: millisecondes sur 3 chiffres
 * @return {String} Date formatte
 */

Date.prototype.format = function (format) {
	var	token = /d{1,2}|m{1,2}|yy(?:yy)?|([HhMs])\1?/g;
	function pad (val, len) {
		val = String(val);
		len = len || 2;
		while (val.length < len) val = "0" + val;
		return val;
	};

	var	d = this.getDate(),
		D = this.getDay(),
		M = this.getMonth(),
		y = this.getFullYear(),
		H = this.getHours(),
		m = this.getMinutes(),
		s = this.getSeconds(),
		L = this.getMilliseconds(),
		flags = {
			d:    d,
			dd:   pad(d),
			M:    M + 1,
			MM:   pad(M + 1),
			yy:   String(y).slice(2),
			yyyy: y,
			h:    H % 12 || 12,
			hh:   pad(H % 12 || 12),
			H:    H,
			HH:   pad(H),
			m:    m,
			mm:   pad(m),
			s:    s,
			ss:   pad(s),
			l:    pad(L, 3)
		};

	return format.replace(token, function ($0) {
		return $0 in flags ? flags[$0] : $0.slice(1, $0.length - 1);
	});
};