/**
 * Extensions du FwMC
 * @version 1.4.0
 * @namespace FwMC.ext
 */
FwMC.ext = {
		/**
		 *  Fonction permettant de d�clarer un step programmatiquement
		 *  @function {public void} declareStep
		 *  <br/>
		 *  @exemple 
		 *  <pre>
		   declareStep({name:"#step_mesComptes",
			 action: "ActivityManager.MesComptesActivity.recupererOperationsCCP",
			 postAction: "ActivityManager.MesComptesActivity.preparerPage",
			 template: "jst/page_comptes.jst",
			 target: "page_comptes",
			 page: "page_comptes"
			 });</pre>

		 *  @param step objet javascript de le forme 
		 *  @... {String} name
		 *  @... {String} action
		 *  @... {String} postAction
		 *  @... {String} template
		 *  @... {String} target
		 *  @... {String} page
		 */
		declareStep: function(step) {
			var stepData = new FwMC.MVC._StepData(step.name);
			stepData.action = step.action;
			stepData.postaction = step.postAction;
			stepData.template = step.template;
			stepData.target = step.target;
			stepData.page = step.page;
			FwMC.MVC._steps.push(stepData);
		}
}


/**
 * Ajout de la directive data-fwmc-hold
 */
FwMC.directive("fwmc-hold", function(action) {
	/**
	 * Objet sp�cifique qui permet de g�rer l'�venement click apr�s un hold
	 * Occulte le click et se d�branche automatiquement
	 * @class ClickAfterHoldEventHandler
	 * @extends EventListener
	 */
	var ClickAfterHoldEventHandler = {
		handleEvent: function(e) {
			e.preventDefault();
			e.stopPropagation();
			document.removeEventListener("click", ClickAfterHoldEventHandler, true);
		}
	};
	var mouseDown = false;
	var holded = false;
	var $this = $(this);
	// Evenements selon si on est touch ou non
	var eventStart, eventEnd;
	if (FwMC.Device.hasTouch()) {
		eventStart = "touchstart";
		eventEnd = ["touchend"];
		eventMove = ["touchmove"];
	} else {
		eventStart = "mousedown";
		eventEnd = ["mouseup"];
		eventMove = ["mousemove"];
	}
	$this.on(eventStart, function(e) {
		mouseDown = true;
		var that = this;
		setTimeout(function() {
			if(mouseDown) {
				var fonctionAction = new Function("e", action);
				fonctionAction.call(that, e);
				holded = true;
			}
		}, 650);
	});
	// Pour les evenements de fin on marque le mouseDown a false
	// Puis on attache l'evenement d'occultation du click qui s'enlevera tout seul au bout de 50ms
	eventEnd.forEach(function(name) {
		$(document).on(name, function(e) {
			mouseDown = false;
			if (holded) {
				holded = false;
				document.addEventListener("click", ClickAfterHoldEventHandler, true);
				setTimeout(function() {
					document.removeEventListener("click", ClickAfterHoldEventHandler, true);
				}, 50);
			}
		});
	});
	// Si on bouge on annule le mouse down
	eventMove.forEach(function(name) {
		$(document).on(name, function(e) {
			mouseDown = false;
		});
	});
	// Memory leak safe !
	$this = null;
});

/**
 * Surcharge de l'execute action pour ajouter automatiquement le spinner s'il est present
 */
/*(function() {
	var oldExecuteAction = FwMC.MVC._doAction;
	FwMC.MVC._doAction = function(actionName,hashWithParameters) {
		if (window.LbpSpinner) {
			window.LbpSpinner.showSpinner({'texte': 'Chargement'}, null, null);
		}
		try {
			var retour = oldExecuteAction(actionName,hashWithParameters);
		} catch(e) {
			throw e;
		} finally {
			if (window.LbpSpinner) {
				window.LbpSpinner.hideSpinner(null, null, null);
			}
		}
		
		return retour;
	}	
})();*/